"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var os_1 = require("os");
var fs_1 = require("fs");
var path_1 = require("path");
var readPkgUp = require('read-pkg-up');
var config_1 = require("./config");
var ConfigProvider = /** @class */ (function () {
    function ConfigProvider(rootPath) {
        this.rootPath = rootPath;
    }
    ConfigProvider.prototype.getConfig = function () {
        if (this.isBootstrappedWithCreateReactApp(this.rootPath)) {
            return config_1.default.craConfigProvider();
        }
        else if (this.usesJestCli()) {
            return config_1.default.jestCliConfigProvider(this.rootPath);
        }
        return config_1.default.defaultConfigProvider(this.rootPath);
    };
    ConfigProvider.prototype.usesJestCli = function () {
        var results = readPkgUp.sync({
            cwd: this.rootPath
        });
        return Boolean(results.pkg.dependencies['jest-cli'] ||
            results.pkg.devDependencies['jest-cli']);
    };
    ConfigProvider.prototype.isBootstrappedWithCreateReactApp = function (rootPath) {
        return (this.hasExecutable(rootPath, 'node_modules/.bin/react-scripts') ||
            this.hasExecutable(rootPath, 'node_modules/react-scripts/node_modules/.bin/jest') ||
            this.hasExecutable(rootPath, 'node_modules/react-native-scripts'));
    };
    ConfigProvider.prototype.hasExecutable = function (rootPath, executablePath) {
        var ext = os_1.platform() === 'win32' ? '.cmd' : '';
        var absolutePath = path_1.join(rootPath, executablePath + ext);
        return fs_1.existsSync(absolutePath);
    };
    return ConfigProvider;
}());
exports.ConfigProvider = ConfigProvider;
//# sourceMappingURL=configProvider.js.map