"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var micromatch = require('micromatch');
var replacePathSepForRegex = require('jest-regex-util').replacePathSepForRegex;
var globsToMatcher = function (globs) {
    if (globs == null || globs.length === 0) {
        return function () { return true; };
    }
    var matchers = globs.map(function (each) { return micromatch.matcher(each, { dot: true }); });
    return function (value) { return matchers.some(function (each) { return each(value); }); };
};
var pathToRegex = function (p) { return replacePathSepForRegex(p); };
var regexToMatcher = function (testRegex) {
    if (!testRegex) {
        return function () { return true; };
    }
    var regex = new RegExp(pathToRegex(testRegex));
    return function (value) { return regex.test(value); };
};
function getTestPatternsMatcher(rootPath, config) {
    var matcher = function () { return ({}); };
    if (config.testMatch && config.testMatch.length) {
        matcher = globsToMatcher(config.testMatch.map(function (match) { return replaceRootDirInPath(rootPath, match); }));
    }
    else if (config.testRegex) {
        matcher = regexToMatcher(config.testRegex);
    }
    return matcher;
}
exports.getTestPatternsMatcher = getTestPatternsMatcher;
function replaceRootDirInPath(rootDir, filePath) {
    if (!/^<rootDir>/.test(filePath)) {
        return filePath;
    }
    return path_1.resolve(rootDir, path_1.normalize('./' + filePath.substr('<rootDir>'.length)));
}
//# sourceMappingURL=fileMatcher.js.map